import sys


def main(args=None):
    if args is None:
        args = sys.argv[1:]

    print("juliet command mode is under development. In the meantime, use the juliet.py script.")

    # Do argument parsing here (eg. with argparse) and anything else
    # you want your project to do.

if __name__ == "__main__":
    main()
